summaryrefslogtreecommitdiffstats
path: root/style/lipstik.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:13:45 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:13:45 -0600
commit153dafe0226035d811c078de9d048b3980cab3ed (patch)
tree1ccef27a9afef3dc70e6e94c9dc87f34c20a7611 /style/lipstik.h
parentc1751ea5db2067176d258974c054e3af51ff48e5 (diff)
downloadtde-style-lipstik-153dafe0226035d811c078de9d048b3980cab3ed.tar.gz
tde-style-lipstik-153dafe0226035d811c078de9d048b3980cab3ed.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'style/lipstik.h')
-rw-r--r--style/lipstik.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/style/lipstik.h b/style/lipstik.h
index 4ce29e6..f68d02f 100644
--- a/style/lipstik.h
+++ b/style/lipstik.h
@@ -243,7 +243,7 @@ protected:
bool mouseOver = false,
bool horizontal = true,
bool enabled = true,
- bool khtmlMode = false) const;
+ bool tdehtmlMode = false) const;
void renderPanel(TQPainter *p,
const TQRect &r,
@@ -279,7 +279,7 @@ protected:
virtual bool objectEventHandler( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void* source, TQEvent *e );
protected slots:
- void khtmlWidgetDestroyed(TQObject* w);
+ void tdehtmlWidgetDestroyed(TQObject* w);
//Animation slots.
void updateProgressPos();
@@ -339,8 +339,8 @@ private:
TQColor _defaultMenuStripeColor;
// TQColor _arrowColor;
- // track khtml widgets.
- TQMap<const TQWidget*,bool> khtmlWidgets;
+ // track tdehtml widgets.
+ TQMap<const TQWidget*,bool> tdehtmlWidgets;
//Animation support.
TQMap<TQWidget*, int> progAnimWidgets;